asr.test.mocks.gpaw.kpt\_descriptor
===================================

.. automodule:: asr.test.mocks.gpaw.kpt_descriptor

   
   
   .. rubric:: Functions

   
   .. autofunction:: kpts2sizeandoffsets
   .. autofunction:: to1bz
   
   

   
   
   

   
   
   